@@ -18,7 +18,7 @@ use XML::Feed;
 use vars qw{$VERSION};
 
 BEGIN {
-  $VERSION = '1.1.2';
+  $VERSION = '2.0.0';
 }
 
 with 'MooseX::Traits';
@@ -153,7 +153,8 @@ Attempt to fetch a web page and a returns a L<URI::Fetch::Response> object.
 =cut
 
 sub fetch_page {
-  my ($self, $url) = @_;
+  my $self = shift;
+  my ($url) = @_;
   return URI::Fetch->fetch(
     $url,
     UserAgent     => $self->ua,
@@ -174,7 +175,8 @@ NB: This method also modifies the contents of L</feeds>.
 =cut
 
 sub fetch_feeds {
-  my ($self, $feeds) = @_;
+  my $self = shift;
+  my ($feeds) = @_;
 
   my @valid_feeds;
   for my $feed (@$feeds) {
@@ -219,7 +221,8 @@ Returns a combined list of L<Perlanet::Entry> objects from all given feeds.
 =cut
 
 sub select_entries {
-  my ($self, $feeds) = @_;
+  my $self = shift;
+  my ($feeds) = @_;
 
   my @feed_entries;
   for my $feed (@$feeds) {
@@ -233,8 +236,6 @@ sub select_entries {
 
     push @feed_entries,
       map {
-        $_->title($feed->title . ': ' . $_->title);
-
         # Problem with XML::Feed's conversion of RSS to Atom
         if ($_->issued && ! $_->modified) {
           $_->modified($_->issued);
@@ -263,7 +264,8 @@ Takes a list of L<Perlanet::Entry>s, and returns an ordered list.
 =cut
 
 sub sort_entries {
-  my ($self, $entries) = @_;
+  my $self = shift;
+  my ($entries) = @_;
   my $day_zero = DateTime->from_epoch(epoch => 0);
 
   my @entries;
@@ -307,7 +309,8 @@ that is the actual feed for the planet.
 =cut
 
 sub build_feed {
-  my ($self, $entries) = @_;
+  my $self = shift;
+  my ($entries) = @_;
 
   my $self_url = $self->self_link;
 
@@ -336,7 +339,8 @@ Takes a HTML string and returns a "cleaned" HTML string.
 =cut
 
 sub clean_html {
-  my ($self, $entry) = @_;
+  my $self = shift;
+  my ($entry) = @_;
   return $entry;
 }
 
@@ -350,7 +354,8 @@ cleaned entries.
 =cut
 
 sub clean_entries {
-  my ($self, $entries) = @_;
+  my $self = shift;
+  my ($entries) = @_;
 
   my @clean_entries;
 
@@ -384,7 +389,8 @@ Takes a L<Perlanet::Feed> as input (as generated by L<build_feed>.
 =cut
 
 sub render {
-  my ($self, $feed) = @_;
+  my $self = shift;
+  my ($feed) = @_;
 }
 
 =head2 run
@@ -405,6 +411,9 @@ sub run {
   $self->render($feed);
 }
 
+no Moose;
+__PACKAGE__->meta->make_immutable;
+
 =head1 TO DO
 
 See L<http://wiki.github.com/davorg/perlanet/issues>
