@@ -3,9 +3,6 @@ package Perlanet::Trait::Cache;
 use strict;
 use warnings;
 
-use 5.6.0;
-our $VERSION = '0.58';
-
 use Moose::Role;
 use namespace::autoclean;
 
@@ -40,7 +37,8 @@ has 'cache'=> (
 
 around 'fetch_page' => sub {
   my $orig = shift;
-  my ($self, $url) = @_;
+  my $self = shift;
+  my ($url) = @_;
   return URI::Fetch->fetch(
     $url,
     UserAgent     => $self->ua,
