@@ -108,7 +108,8 @@ sub _build_scrubber {
 
 around 'clean_html' => sub {
   my $orig = shift;
-  my ($self, $html) = @_;
+  my $self = shift;
+  my ($html) = @_;
   $html = $self->$orig($html);
   my $scrubbed = $self->scrubber->scrub($html);
   return $scrubbed;
